# Sanitary

[![PyPI - Version](https://img.shields.io/pypi/v/sanitary.svg)](https://pypi.org/project/sanitary)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/sanitary.svg)](https://pypi.org/project/sanitary)

Sanitary is a utility for removing or replacing sensitive data from data structures.


## Installation

```console
pip install sanitary
```

## License

`sanitary` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
